@@ -13,7 +13,7 @@ use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/VCS::Which::Plugin/;
-use Path::Class;
+use Path::Tiny;
 use File::chdir;
 use Contextual::Return;
 
@@ -40,7 +40,7 @@ sub used {
     my ( $self, $dir ) = @_;
 
     if (-f $dir) {
-        $dir = file($dir)->parent;
+        $dir = path($dir)->parent;
     }
 
     croak "$dir is not a directory!" if !-d $dir;
@@ -91,7 +91,7 @@ sub log {
     my ($self, $file, @args) = @_;
 
     my $args = join ' ', @args;
-    my $dir  = -d $file ? dir $file : file($file)->parent;
+    my $dir  = -d $file ? path($file) : path($file)->parent;
 
     local $CWD = $dir;
     return
