@@ -17,7 +17,7 @@ use Path::Tiny;
 use File::chdir;
 use Contextual::Return;
 
-our $VERSION = version->new('0.5.8');
+our $VERSION = version->new('0.5.9');
 our $name    = 'Git';
 our $exe     = 'git';
 our $meta    = '.git';
@@ -235,21 +235,21 @@ sub status {
     $status =~ s/^no \s+ changes (.*?) $//xms;
     chomp $status;
 
-    my @both = split /\n?[#]\s+both\s+modified:\s+/, $status;
+    my @both = split /\n?[#]?\s+both\s+modified:\s+/, $status;
     if ( @both > 1 ) {
         shift @both;
         $both[-1] =~ s/\n.*//xms;
         $status{both} = \@both;
     }
 
-    my @modified = split /\n?[#]\s+modified:\s+/, $status;
+    my @modified = split /\n?[#]?\s+modified:\s+/, $status;
     if ( @modified > 1 ) {
         shift @modified;
         $modified[-1] =~ s/\n.*//xms;
         $status{modified} = \@modified;
     }
 
-    my @added = split /\n?[#]\s+new\sfile:\s+/, $status;
+    my @added = split /\n?[#]?\s+new\sfile:\s+/, $status;
     if ( @added > 1 ) {
         shift @added;
         $added[-1] =~ s/\n.*//xms;
@@ -259,9 +259,13 @@ sub status {
     my @untracked = split /Untracked files:\n/, $status;
     if ( @untracked > 1 ) {
         my $untracked = pop @untracked;
-        $untracked =~ s/^[#].*?\n//xms;
-        $untracked =~ s/^[#].*?\n//xms;
-        $status{untracked} = [ grep {$_} map {chomp; $_} split /\n?[#]\s+/, $untracked ];
+        if ($untracked =~ s/^\s+[(]use \s+ "git \s+ add \s+ [^"]+" \s+ [^)]+\)\n\n//xms) {
+            chomp $untracked;
+        }
+        else {
+            $untracked =~ s/^[#].*?\n//gxms;
+        }
+        $status{untracked} = [ grep {$_} map {chomp; $_} split /\n?[#]?\s+/, $untracked ];
     }
 
     $status{merge} = $status =~ /
@@ -296,7 +300,7 @@ VCS::Which::Plugin::Git - The Git plugin for VCS::Which
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin::Git version 0.5.8.
+This documentation refers to VCS::Which::Plugin::Git version 0.5.9.
 
 =head1 SYNOPSIS
 
